@@ -42,13 +42,21 @@ int GetFstThreads()
 #endif
 }
 
-int SetFstThreads(int nrOfThreads)
+
+int ThreadsFst(int nrOfThreads)
 {
 	int oldNrOfThreads = GetFstThreads();
 	FstThreads = nrOfThreads;
 	return oldNrOfThreads;
 }
 
+
+void SetThreads(int nrOfThreads)
+{
+  FstThreads = nrOfThreads;
+}
+
+
 bool HasOpenMP()
 {
 #ifdef _OPENMP
